pub struct Ed25519PublicKey(pub [u8; 32]);Expand description
Ed25519 public key (32 bytes)
Tuple Fields
0: [u8; 32]Trait Implementations
Sourceimpl AsRef<[u8]> for Ed25519PublicKey
impl AsRef<[u8]> for Ed25519PublicKey
Sourceimpl Clone for Ed25519PublicKey
impl Clone for Ed25519PublicKey
Sourcefn clone(&self) -> Ed25519PublicKey
fn clone(&self) -> Ed25519PublicKey
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for Ed25519PublicKey
Sourceimpl Debug for Ed25519PublicKey
impl Debug for Ed25519PublicKey
Sourceimpl Decode for Ed25519PublicKey
impl Decode for Ed25519PublicKey
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for Ed25519PublicKey
impl<'de> Deserialize<'de> for Ed25519PublicKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for Ed25519PublicKey
impl Encode for Ed25519PublicKey
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>(
&self,
f: __CodecUsingEncodedCallback,
) -> __CodecOutputReturn
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>( &self, f: __CodecUsingEncodedCallback, ) -> __CodecOutputReturn
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for Ed25519PublicKey
impl Eq for Ed25519PublicKey
Sourceimpl Hash for Ed25519PublicKey
impl Hash for Ed25519PublicKey
Sourceimpl PartialEq for Ed25519PublicKey
impl PartialEq for Ed25519PublicKey
Sourcefn eq(&self, other: &Ed25519PublicKey) -> bool
fn eq(&self, other: &Ed25519PublicKey) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Ed25519PublicKey
impl Serialize for Ed25519PublicKey
impl StructuralPartialEq for Ed25519PublicKey