pub struct Ed25519Signature(pub [u8; 64]);Expand description
Ed25519 signature (64 bytes)
Tuple Fields
0: [u8; 64]Trait Implementations
Sourceimpl Clone for Ed25519Signature
impl Clone for Ed25519Signature
Sourcefn clone(&self) -> Ed25519Signature
fn clone(&self) -> Ed25519Signature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for Ed25519Signature
Sourceimpl Debug for Ed25519Signature
impl Debug for Ed25519Signature
Sourceimpl Decode for Ed25519Signature
impl Decode for Ed25519Signature
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for Ed25519Signature
impl<'de> Deserialize<'de> for Ed25519Signature
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for Ed25519Signature
impl Encode for Ed25519Signature
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>(
&self,
f: __CodecUsingEncodedCallback,
) -> __CodecOutputReturn
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>( &self, f: __CodecUsingEncodedCallback, ) -> __CodecOutputReturn
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for Ed25519Signature
impl Eq for Ed25519Signature
Sourceimpl Hash for Ed25519Signature
impl Hash for Ed25519Signature
Sourceimpl PartialEq for Ed25519Signature
impl PartialEq for Ed25519Signature
Sourcefn eq(&self, other: &Ed25519Signature) -> bool
fn eq(&self, other: &Ed25519Signature) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Ed25519Signature
impl Serialize for Ed25519Signature
impl StructuralPartialEq for Ed25519Signature