pub struct BlockNumber(pub u32);Expand description
Block number in the chain
Tuple Fields
0: u32Trait Implementations
Sourceimpl Add<u32> for BlockNumber
impl Add<u32> for BlockNumber
Sourceimpl Clone for BlockNumber
impl Clone for BlockNumber
Sourcefn clone(&self) -> BlockNumber
fn clone(&self) -> BlockNumber
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BlockNumber
Sourceimpl Debug for BlockNumber
impl Debug for BlockNumber
Sourceimpl Decode for BlockNumber
impl Decode for BlockNumber
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl<'de> Deserialize<'de> for BlockNumber
impl<'de> Deserialize<'de> for BlockNumber
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for BlockNumber
impl Encode for BlockNumber
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>(
&self,
f: __CodecUsingEncodedCallback,
) -> __CodecOutputReturn
fn using_encoded<__CodecOutputReturn, __CodecUsingEncodedCallback: FnOnce(&[u8]) -> __CodecOutputReturn>( &self, f: __CodecUsingEncodedCallback, ) -> __CodecOutputReturn
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
impl EncodeLike for BlockNumber
impl Eq for BlockNumber
Sourceimpl From<BlockNumber> for u32
impl From<BlockNumber> for u32
Sourcefn from(block_number: BlockNumber) -> Self
fn from(block_number: BlockNumber) -> Self
Converts to this type from the input type.
Sourceimpl From<u32> for BlockNumber
impl From<u32> for BlockNumber
Sourceimpl Hash for BlockNumber
impl Hash for BlockNumber
Sourceimpl Ord for BlockNumber
impl Ord for BlockNumber
Sourcefn cmp(&self, other: &BlockNumber) -> Ordering
fn cmp(&self, other: &BlockNumber) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BlockNumber
impl PartialEq for BlockNumber
Sourcefn eq(&self, other: &BlockNumber) -> bool
fn eq(&self, other: &BlockNumber) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BlockNumber
impl PartialOrd for BlockNumber
Sourceimpl Serialize for BlockNumber
impl Serialize for BlockNumber
impl StructuralPartialEq for BlockNumber